==> wikbook.core-0.9.31-sources.jar: org/wikbook/core/render/docbook/content/block/CalloutTransformer.java <==
/*
 * Copyright (C) 2010 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wikbook.core.render.docbook.content.block;

import org.wikbook.core.model.content.block.CalloutElement;
import org.wikbook.core.render.docbook.ElementTransformer;
import org.wikbook.core.xml.ElementEmitter;
import org.wikbook.core.xml.XMLEmitter;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public class CalloutTransformer extends ElementTransformer<CalloutElement>
{

   @Override
   public void write(CalloutElement element, XMLEmitter emitter)
   {
      ElementEmitter calloutXML = emitter.element("callout");

      //
      StringBuffer sb = new StringBuffer();
      for (String coId : element.getIds().keySet())
      {
         if (sb.length() > 0)
         {
            sb.append(" ");
         }
         sb.append(coId).append("-co");
      }

      //
      calloutXML.withAttribute("arearefs", sb.toString());

      //
      write(element.getContent(), false, calloutXML);
   }
}

==> wikbook.core-0.9.43-sources.jar: org/wikbook/core/render/docbook/content/block/CalloutTransformer.java <==
/*
 * Copyright (C) 2010 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wikbook.core.render.docbook.content.block;

import org.wikbook.core.model.content.block.CalloutElement;
import org.wikbook.core.render.docbook.ElementTransformer;
import org.wikbook.core.xml.ElementEmitter;
import org.wikbook.core.xml.XMLEmitter;
import org.wikbook.text.Position;

import java.util.LinkedHashMap;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public class CalloutTransformer extends ElementTransformer<CalloutElement>
{

   @Override
   public void write(CalloutElement element, XMLEmitter emitter)
   {
      ElementEmitter calloutXML = emitter.element("callout");

      //
      LinkedHashMap<String,Position> ids = element.getIds();
      if (ids.size() > 0)
      {
         calloutXML.withAttribute("arearefs", ids.keySet().iterator().next() + "_");
      }

      //

      //
      write(element.getContent(), false, calloutXML);
   }
}
